<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>Man</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>Tir</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>Ons</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>Fre</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>Lør</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>Søn</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>Skyet</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>Mest skyet</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>Delvist skyet</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>Let regn</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>Byger</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>Regn</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>Regn om formiddagen</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>Tåge</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>Enkelte byger</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>Mest solskin</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>Solskin</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>Enkelte snebyger</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>Skyet om formiddagen, sol om eftermiddagen</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>Enkelte tordenbyger</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>Nogle tordenbyger</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>Regn om eftermiddagen</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>Regn og blæst om eftermiddagen</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>Regn- eller snebyger</translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>Enkelte snebyger</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>Skyet og blæsende</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>Vindstød</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>Mest skyet og blæsende</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>Regn og torden</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>Delvist skyet og blæsende</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>Regn- eller snebyger om formiddagen</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>Let regn og blæsende</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>Byger og blæsende</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>Mest sol og blæsende</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>Byger</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>Regn og blæsende</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>Enkelte byger og blæsende</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>Enkelte kraftige storme</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>Tordenbyger om eftermiddagen</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>Tordenbyger</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>Sol og blæsende</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>Tordenbyger om formiddagen</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>Regn om formiddagen</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>Enkelte tordenbyger og blæsende</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>Regn eller sne</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>Enkelte tordenbyger og blæsende</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>Byger og blæsende om formiddagen</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>Enkelte snebyger</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>Sne/isslag og blæsende</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>Sne eller regn</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>Let regn om formiddagen</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>Let regn om eftermiddagen</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>Regn om eftermiddagen</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>Snebyger</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>Regn eller sne</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>Regn eller sne om eftermiddagen</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>Enkelte byger og blæsende</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>Sne og blæsende</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>Regn- og snebyger om eftermiddagen</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>Regn, sne og blæsende om eftermiddagen</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>Regn- eller snebyger og blæsende</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>Regn eller sne og blæsende</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>Let sne</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>Sne om eftermiddagen</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>Enkelte snebyger og blæsende</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>Let sne og blæsende</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>Blandet vintervejr</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>Blandet vintervejr om formiddagen</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>Kraftig regn/isslag</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>Let sne om formiddagen</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>Regn eller isslag</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>Tordenbyger og blæsende</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>Enkelte dryp</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>Snebyger om formiddagen</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>Skyet om formiddagen, sol og blæsende om eftermiddagen</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>Regn, sne og blæsende om formiddagen</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>Regn eller sne og blæsende</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>Sne og blandet vintervejr</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>Snebyger og blæsende om eftermiddagen</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>Sne/isslag eller regn</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>Kraftig regn</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>Regn eller isslag om formiddagen</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>Snebyger og blæsende om formiddagen</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>Let sne og blæsende om formiddagen</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>Let regn og blæsende om eftermiddagen</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>Let blandet vintervejr om formiddagen</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>Let sne og blæsende om eftermiddagen</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>Kraftig regn og blæsende</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>Snebyger om eftermiddagen</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>Sne eller regn og blæsende</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>Let regn/isslag om eftermiddagen</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>Sne om formiddagen</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>Sne eller isslag</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>Blandet vintervejr og blæsende</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>Let sne om eftermiddagen</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>Silende regn om formiddagen</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>Kraftige storme og blæst</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>Silende regn om eftermiddagen</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>Silende regnvejr</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>Let regn og blæsende om eftermiddagen</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>Regn og blæst om formiddagen</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>Blandet vintervejr eller sne</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>Snebyger og blæsende</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>Lette regnbyger</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>Let regn med torden</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>Let silende regn</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>Diset</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>Røg</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>Diset</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>Lette snebyger</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>Lette snebyger og blæsende</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Klart</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>Enkelte skyer</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>Pænt</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <source>NNE</source>
        <translation>NNØ</translation>
    </message>
    <message>
        <source>NE</source>
        <translation>NØ</translation>
    </message>
    <message>
        <source>E</source>
        <translation>Ø</translation>
    </message>
    <message>
        <source>SE</source>
        <translation>SØ</translation>
    </message>
    <message>
        <source>SSE</source>
        <translation>SSØ</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>SSV</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>SV</translation>
    </message>
    <message>
        <source>W</source>
        <translation>V</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>NV</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation>NNV</translation>
    </message>
    <message>
        <source>ENE</source>
        <translation>ØNØ</translation>
    </message>
    <message>
        <source>ESE</source>
        <translation>ØSØ</translation>
    </message>
    <message>
        <source>WSW</source>
        <translation>VSV</translation>
    </message>
    <message>
        <source>WNW</source>
        <translation>VNV</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Indlæser...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ henter vejr-data ... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>Nuværende forhold</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Luftfugtighed</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Lufttryk</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Vind</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Sigtbarhed</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Lufttemperatur</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>UV-index</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>De kommende dage</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>Min</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>Max</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>Dagens vejrudsigt</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>Vejret i morgen</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Vejrudsigt for</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Doppler Radar</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Kortet er ikke tilgængeligt</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Indtast postnr</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Vejr-opsætning</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Gem med &apos;i&apos;. Afbryd med &apos;Esc&apos;</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>Regn</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>Blandet/Isslag</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>Sne</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>Let</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>Kraftig</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation>Koldt</translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation>Koldest</translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation>Sky temperatur</translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation> er ugyldig)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>   Ingen lokation sat. Læs venligst README-filen</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>Konfigurerer MythWeather...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Brug pil til højre til at vælge enheds-konvertering...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Vejr-enheder</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Lokation</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Aggressivitet</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Konfiguration gemt...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>Henter vejr-data...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Brug pil til højre for at vælge din lokation...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Brug pil til højre til at vælge aggressivitets-niveau...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation> 1  Høj-hastigheds forbindelse</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation> 8  Mellem-hastigheds forbindelse</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation> 15 Lav-hastigheds forbindelse</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>Henter grundlæggende vejr-data...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>Opdaterer vejr-data...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Roligt</translation>
    </message>
    <message>
        <source> at </source>
        <translation> med </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Ubegrænset</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation> (minimalt)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation> (moderat)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation> (høj)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation> (ekstrem)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Dagens højeste temperatur er på ca. </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation> grader, og den laveste er ca. </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation> grader. Lige nu er luftfugtigheden </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% og vinden blæser</translation>
    </message>
    <message>
        <source> calm.</source>
        <translation> roligt.</translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation> med </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation> mph fra </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation> km/t fra </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation> Sightbarheden vil være ubegrænset i dag.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation> Sigtbarheden er ukendt.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation> Sigtbarheden er </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation> mil.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation> km.</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Søndag</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Mandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tirsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Lørdag</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Dato-fejl</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>I morgen når temperaturen op omkring </translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Forventede forhold: </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Vejr-data fra: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Opdaterer...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation> (Ikke al information er tilgængelig)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** Ugyldigt område-ID eller server-fejl ***</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation>Imperial (Fahrenheit, tommer, osv.)</translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation>Metrisk (Celcius, kPa, osv.)</translation>
    </message>
    <message>
        <source> F</source>
        <translation> F</translation>
    </message>
    <message>
        <source> C</source>
        <translation> C</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation> - PAUSE -</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="obsolete">Doppler Radar</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="obsolete">satellit billede</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to try again without animated radar maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to abort.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
